@@ -25,6 +25,7 @@
 #import "NSString+SupportedMedia.h"
 #import "UIDevice+VLC.h"
 #import "VLCHTTPUploaderController.h"
+#import "VLCMetaData.h"
 
 #if TARGET_OS_IOS
 #import "VLCThumbnailsCache.h"
@@ -154,18 +155,8 @@
                 return [[HTTPErrorResponse alloc] initWithErrorCode:404];
             }
 
-            NSData *theData;
-            NSString *contentType;
-
-            /* devices category 3 and faster include HW accelerated JPEG encoding
-             * so we can make our transfers faster by using waaay smaller images */
-            if ([[UIDevice currentDevice] VLCSpeedCategory] < 3) {
-                theData = UIImagePNGRepresentation([VLCThumbnailsCache thumbnailForManagedObject:mo]);
-                contentType = @"image/png";
-            } else {
-                theData = UIImageJPEGRepresentation([VLCThumbnailsCache thumbnailForManagedObject:mo], .9);
-                contentType = @"image/jpg";
-            }
+            NSData *theData = UIImageJPEGRepresentation([VLCThumbnailsCache thumbnailForManagedObject:mo], .9);
+            NSString *contentType = @"image/jpg";
 
             if (theData) {
                 HTTPDataResponse *dataResponse = [[HTTPDataResponse alloc] initWithData:theData];
@@ -464,22 +455,21 @@
      */
 
     VLCPlaybackController *vpc = [VLCPlaybackController sharedInstance];
-    if (!vpc.activePlaybackSession) {
+    if (!vpc.isPlaying) {
         return [[HTTPErrorResponse alloc] initWithErrorCode:404];
     }
-    VLCMediaPlayer *player = vpc.mediaPlayer;
-    VLCMedia *media = player.media;
+    VLCMedia *media = [vpc currentlyPlayingMedia];
     if (!media) {
         return [[HTTPErrorResponse alloc] initWithErrorCode:404];
     }
 
-    NSString *mediaTitle = vpc.mediaTitle;
+    NSString *mediaTitle = vpc.metadata.title;
     if (!mediaTitle)
         mediaTitle = @"";
     NSDictionary *mediaDict = @{ @"id" : media.url.absoluteString,
                                  @"title" : mediaTitle,
-                                 @"duration" : @(media.length.intValue)};
-    NSDictionary *returnDict = @{ @"currentTime" : @(player.time.intValue),
+                                 @"duration" : @([vpc mediaDuration])};
+    NSDictionary *returnDict = @{ @"currentTime" : @([vpc playedTime].intValue),
                                   @"media" : mediaDict };
 
     NSError *error;
@@ -535,7 +525,7 @@
      */
 
     VLCPlaybackController *vpc = [VLCPlaybackController sharedInstance];
-    if (!vpc.activePlaybackSession || !vpc.mediaList) {
+    if (!vpc.isPlaying || !vpc.mediaList) {
         return [[HTTPErrorResponse alloc] initWithErrorCode:404];
     }
 
@@ -655,18 +645,16 @@
     [_receivedFiles addObject:path];
 
     VLCPlaybackController *vpc = [VLCPlaybackController sharedInstance];
-    BOOL needsMediaList = NO;
     VLCMediaList *mediaList = vpc.mediaList;
 
     if (!mediaList) {
         mediaList = [[VLCMediaList alloc] init];
-        needsMediaList = YES;
     }
 
     [mediaList addMedia:[VLCMedia mediaWithURL:[NSURL fileURLWithPath:path]]];
 
-    if (needsMediaList) {
-        [vpc playMediaList:mediaList firstIndex:0];
+    if (!vpc.mediaList) {
+        [vpc playMediaList:mediaList firstIndex:0 subtitlesFilePath:nil];
     }
 
     VLCFullscreenMovieTVViewController *movieVC = [VLCFullscreenMovieTVViewController fullscreenMovieTVViewController];
