@@ -150,7 +150,6 @@
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
     [defaults setBool:self.privateToggleSwitch.on forKey:kVLCPrivateWebStreaming];
     [defaults setBool:self.ScanSubToggleSwitch.on forKey:kVLChttpScanSubtitle];
-    [defaults synchronize];
 
     /* force update before we leave */
     [[NSUbiquitousKeyValueStore defaultStore] synchronize];
@@ -193,7 +192,7 @@
             [self.historyTableView reloadData];
         }
         [self.urlField resignFirstResponder];
-        [self performSelectorInBackground:@selector(_openURLStringAndDismiss:) withObject:self.urlField.text];
+        [self _openURLStringAndDismiss:self.urlField.text];
     }
 }
 
@@ -317,7 +316,7 @@
 - (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
 {
     [self.historyTableView deselectRowAtIndexPath:indexPath animated:NO];
-    [self performSelectorInBackground:@selector(_openURLStringAndDismiss:) withObject:_recentURLs[indexPath.row]];
+    [self _openURLStringAndDismiss:_recentURLs[indexPath.row]];
 }
 
 - (void)tableView:(UITableView *)tableView
@@ -355,12 +354,14 @@ forRowAtIndexPath:(NSIndexPath *)indexPath
     NSURL *URLscheme = [NSURL URLWithString:url];
     NSString *URLofSubtitle = nil;
 
-    if ([URLscheme.scheme isEqualToString:@"http"])
-        if (self.ScanSubToggleSwitch.on)
-            URLofSubtitle = [self _checkURLofSubtitle:url];
+    if ([URLscheme.scheme isEqualToString:@"http"] && self.ScanSubToggleSwitch.on) {
+        URLofSubtitle = [self _checkURLofSubtitle:url];
+    }
 
-    VLCPlaybackController *vpc = [VLCPlaybackController sharedInstance];
-    [vpc playURL:[NSURL URLWithString:url] subtitlesFilePath:URLofSubtitle];
+    VLCMedia *media = [VLCMedia mediaWithURL:[NSURL URLWithString:url]];
+    VLCMediaList *medialist = [[VLCMediaList alloc] init];
+    [medialist addMedia:media];
+    [[VLCPlaybackController sharedInstance] playMediaList:medialist firstIndex:0 subtitlesFilePath:URLofSubtitle];
 }
 
 - (NSString *)_checkURLofSubtitle:(NSString *)url
