@@ -45,7 +45,7 @@
 {
     self.isSelectedView.hidden = !editing;
 
-    if (!([_mediaObject isKindOfClass:[MLFile class]] && [_mediaObject.labels count] > 0))
+    if (!([_mediaObject isKindOfClass:[MLFile class]] && [((MLFile *)_mediaObject).labels count] > 0))
         [self shake:editing];
     [self selectionUpdate];
     [self _updatedDisplayedInformationForKeyPath:@"editing"];
@@ -198,7 +198,7 @@
 {
     self.thumbnailView.contentMode = UIViewContentModeScaleAspectFill;
     if ([self.mediaObject isKindOfClass:[MLFile class]]) {
-        [self _configureForMLFile:self.mediaObject];
+        [self _configureForMLFile:(MLFile *)self.mediaObject];
     } else if ([self.mediaObject isKindOfClass:[MLLabel class]]) {
         [self _configureForFolder:(MLLabel *)self.mediaObject];
     } else if ([self.mediaObject isKindOfClass:[MLAlbum class]]) {
@@ -349,7 +349,7 @@
 
         MLFile *theFile;
         if ([self.mediaObject isKindOfClass:[MLFile class]])
-            theFile = self.mediaObject;
+            theFile = (MLFile *)self.mediaObject;
         else if ([self.mediaObject isKindOfClass:[MLShowEpisode class]])
             theFile = [[(MLShowEpisode *)self.mediaObject files]anyObject];
         else if ([self.mediaObject isKindOfClass:[MLAlbumTrack class]])
@@ -521,4 +521,19 @@
     self.thumbnailView.image = [VLCThumbnailsCache thumbnailForManagedObject:self.mediaObject refreshCache:YES];
 }
 
+- (void)prepareForReuse
+{
+    [super prepareForReuse];
+    self.mediaObject = nil;
+    self.thumbnailView.image = nil;
+    self.titleLabel.text = @"";
+    self.subtitleLabel.text = @"";
+    self.mediaIsUnreadView.hidden = YES;
+    self.progressView.hidden = YES;
+    self.metaDataLabel.hidden = YES;
+    self.folderIconView.hidden = YES;
+    self.isSelectedView.hidden = YES;
+    self.metaDataLabel.hidden = YES;
+    self.mediaIsUnreadView.hidden = YES;
+}
 @end
